@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -14,10 +13,12 @@
 
 import os
 import sys
+import warnings
 
 import openstackdocstheme
 
 sys.path.insert(0, os.path.abspath('../..'))
+sys.path.insert(0, os.path.abspath('.'))
 # -- General configuration ----------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
@@ -25,8 +26,12 @@ sys.path.insert(0, os.path.abspath('../..'))
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
+    'enforcer'
 ]
 
+# When True, this will raise an exception that kills sphinx-build.
+enforcer_warnings_as_errors = True
+
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -63,7 +68,12 @@ release = '1.0'
 # These variables are passed to the logabug code via html_context.
 giturl = u'http://git.openstack.org/cgit/openstack/python-openstacksdk/tree/doc/source'
 git_cmd = "/usr/bin/git log | head -n1 | cut -f2 -d' '"
-gitsha = os.popen(git_cmd).read().strip('\n')
+try:
+    gitsha = os.popen(git_cmd).read().strip('\n')
+except Exception:
+    warnings.warn("Can not get git sha.")
+    gitsha = "unknown"
+
 bug_tag = "docs"
 # source tree
 pwd = os.getcwd()
@@ -115,7 +125,8 @@ latex_documents = [
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
-intersphinx_mapping = {'http://docs.python.org/3/': None}
+intersphinx_mapping = {'https://docs.python.org/3/': None,
+                       'http://docs.python-requests.org/en/master/': None}
 
 # Include both the class and __init__ docstrings when describing the class
 autoclass_content = "both"
